=======
History
=======

0.2 Alpha (2021-03-11)
-----------------------

* Added documentation
* Added basic unit tests for each class (SpecificDoses and ExposureMap)
* Added histogram descriptor calculator functions to subroutines.
* Added map making functionality for ExposureMap class, limited consideration of map_options at this stage
* Fixed errors when working with single day test data (but anticipate further issues with this, to be fixed in a later release)


0.1 (2021-03-02)
------------------

* Alpha release on github only, no documentation and limited functionality
